@@ -3,10 +3,9 @@ import cStringIO
 import csv
 from itertools import izip
 
-from ccy import date2juldate
 from dynts.exceptions import FormattingException
 from dynts.backends import istimeseries
-from dynts.utils import asarray, JSONdatainfo
+from dynts.utils import asarray
 
 default_converter = lambda x : x.isoformat()
 
@@ -77,6 +76,8 @@ The unserializer is also included in the directory extras'''
     type = 'json'
     def __call__(self, ts, container = None, desc = False, **kwargs):
         '''Dump timeseries as a JSON string VBA-Excel friendly'''
+        from ccy import date2juldate
+        from dynts.utils.anyjson import JSONdatainfo
         if istimeseries(ts):
             return JSONdatainfo(list(tsiterator(ts, dateconverter=date2juldate, desc = desc)),
                                 info = ts.info)
